@@ -133,6 +133,12 @@ class BaseProcessor(abc.ABC):
         else:
             return key in defaults
 
+    def create_results_folder(self):
+        """Ensure the results folder has been created."""
+
+        results_folder = self.get_instruction_path("subfolder")
+        results_folder.mkdir(parents=True, exist_ok=True)
+
     def get_resolution(self) -> float:
         """Return the resolution from the instruction file. Raise an error if
         not in the instructions."""
@@ -532,6 +538,11 @@ class RawLidarDemGenerator(BaseProcessor):
         Note it currently only considers one LiDAR dataset that can have many tiles.
         See 'get_lidar_file_list' for where to change this."""
 
+        logging.info("Create a raw DEM layer from LiDAR.")
+
+        # Ensure the results folder has been created
+        self.create_results_folder()
+
         # Only include data in addition to LiDAR if the area_threshold is not covered
         area_threshold = 10.0 / 100  # Used to decide if bathymetry should be included
 
@@ -712,6 +723,9 @@ class HydrologicDemGenerator(BaseProcessor):
         """This method executes the geofabrics generation pipeline to produce geofabric
         derivatives."""
 
+        # Ensure the results folder has been created
+        self.create_results_folder()
+
         # Only include data in addition to LiDAR if the area_threshold is not covered
         area_threshold = 10.0 / 100  # Used to decide if bathymetry should be included
 
@@ -763,6 +777,11 @@ class RoughnessLengthGenerator(BaseProcessor):
         """This method executes the geofabrics generation pipeline to produce geofabric
         derivatives."""
 
+        logging.info("Adding a roughness layer to the geofabric.")
+
+        # Ensure the results folder has been created
+        self.create_results_folder()
+
         # create the catchment geometry object
         self.catchment_geometry = self.create_catchment()
 
@@ -1583,7 +1602,10 @@ class RiverBathymetryGenerator(BaseProcessor):
         pipeline to produce a DEM before sampling this to extimate width, slope
         and eventually depth."""
 
-        logging.info("Adding river and fan bathymetry if it doesn't already" "exist.")
+        logging.info("Adding river and fan bathymetry if it doesn't already exist.")
+
+        # Ensure the results folder has been created
+        self.create_results_folder()
 
         # Characterise river channel if not already done - may generate DEMs
         if not self.channel_characteristics_exist():
@@ -1827,7 +1849,7 @@ class DrainBathymetryGenerator(BaseProcessor):
                     open_drains.iloc[drain_index]["end_elevation"],
                 )
             ]
-            for point in row.geoms[1:]:
+            for point in list(row.geoms)[1:]:
                 elevation = float(dem.z.sel(x=point.x, y=point.y, method="nearest"))
                 row_bathymetries.append(
                     elevation
@@ -1954,6 +1976,9 @@ class DrainBathymetryGenerator(BaseProcessor):
             return
         logging.info("Estimating drain and tunnel bed elevation from OpenStreetMap.")
 
+        # Ensure the results folder has been created
+        self.create_results_folder()
+
         # Load in catchment
         self.catchment_geometry = self.create_catchment()
 
